@@ -1,3 +1,4 @@
+{-# LANGUAGE DefaultSignatures, DeriveAnyClass #-}
 {-DHUN| module to compile mediawiki page to latex documents. This module is called from the All module.|DHUN-}
 module Compiler where
 import ImperativeState
@@ -13,15 +14,19 @@ import Data.Set ()
 import Control.Monad.State
 import UrlAnalyse
 import Data.ByteString.UTF8 (toString)
-import Data.ByteString
+import Data.ByteString as B
        hiding (take, reverse, dropWhile, takeWhile, drop, map, concat,
                elem, length, zip, head, filter, minimum, isInfixOf)
+import Data.Serialize as S (encode)
 
-runCompile :: String -> ImperativeMonad ()
-runCompile dir
+runCompile :: String -> FullConfig-> ImperativeMonad ()
+runCompile dir cfg
   = do t <- liftIO $ Tools.readFile (dir </> "input")
-       cr <- return (printPrepareTree (parseit minparsers t))
-       liftIO $ Tools.writeFile (dir </> "output") (show cr)
+       p <- return $ case runMode cfg of
+                       (HTML _) -> minparsers
+                       _ -> parsers
+       cr <- return (printPrepareTree (parseit p t))
+       liftIO $ B.writeFile (dir </> "output") (encode cr)
 
 {-DHUN| main function to compile mediawiki pages   |DHUN-}
 
@@ -37,41 +42,41 @@ compile theRunMode text templates tabs mytitle mylanguage formulas
   b
   = do st <- get
        case theRunMode of
-           StandardTemplates -> return
-                                  (run b mylanguage mytitle (parseit parsers text)
-                                     (parseit parsers text)
-                                     (hostname . fullUrl $ st)
-                                     templates
-                                     tabs
-                                     formulas)
-           UserTemplateFile _ -> return
-                                   (run b mylanguage mytitle (parseit parsers text)
-                                      (parseit parsers text)
-                                      (hostname . fullUrl $ st)
-                                      templates
-                                      tabs
-                                      formulas)
-           HTML -> return
-                     (run b mylanguage mytitle
-                        (printPrepareTree (parseit minparsers text))
-                        (printPrepareTree (parseit minparsers text))
-                        (hostname . fullUrl $ st)
-                        templates
-                        tabs
-                        formulas)
-           Book -> do return
-                        (run b mylanguage mytitle (loadacu st) (loadacu st)
-                           (hostname . fullUrl $ st)
-                           templates
-                           tabs
-                           formulas)
-           ExpandedTemplates -> do return
+           StandardTemplates No -> return
                                      (run b mylanguage mytitle (parseit parsers text)
+                                       (parseit parsers text)
+                                       (hostname . fullUrl $ st)
+                                       templates
+                                       tabs
+                                       formulas)
+           UserTemplateFile No _ -> return
+                                      (run b mylanguage mytitle (parseit parsers text)
                                         (parseit parsers text)
                                         (hostname . fullUrl $ st)
                                         templates
                                         tabs
                                         formulas)
+           HTML No  -> return
+                        (run b mylanguage mytitle
+                         (printPrepareTree (parseit minparsers text))
+                         (printPrepareTree (parseit minparsers text))
+                         (hostname . fullUrl $ st)
+                         templates
+                         tabs
+                         formulas)
+           ExpandedTemplates No -> do return
+                                       (run b mylanguage mytitle (parseit parsers text)
+                                        (parseit parsers text)
+                                        (hostname . fullUrl $ st)
+                                        templates
+                                        tabs
+                                        formulas)
+           _ -> do return
+                        (run b mylanguage mytitle (loadacu st) (loadacu st)
+                           (hostname . fullUrl $ st)
+                           templates
+                           tabs
+                           formulas)
 
 {-DHUN| pathname of the temporary directory of the compiler |DHUN-}
 
