@@ -43,7 +43,7 @@ instance Show MyError where
         show PaperError
           = "Error: The option paper may only be one of A4,A5,B5,letter,legal,executive"
         show ToManyOptionsError
-          = "Error: at most one of the options --internal --templates --message --html may be given"
+          = "Error: at most one of the options --internal --templates --mediawiki --html may be given"
         show ToManyOutputOptionsError
           = "Error: at most one of the options --zip --epub --odt may be given"
         show (NotExcatlyOneError msg)
@@ -97,11 +97,13 @@ data ImageInfo = ImageInfo{wikiFilename :: String,
 
 type ImperativeMonad = ExceptT MyError (StateT ImperativeState IO)
 
-data RunMode = HTML
-             | ExpandedTemplates
-             | StandardTemplates
-             | Book
-             | UserTemplateFile String
+data BookMode = Yes | No
+             deriving (Show, Read, Eq)
+
+data RunMode = HTML BookMode
+             | ExpandedTemplates BookMode 
+             | StandardTemplates BookMode
+             | UserTemplateFile BookMode String
              deriving (Show, Read, Eq)
 
 data SourceMode = Included
@@ -126,7 +128,7 @@ data FullConfig = FullConfig{headers :: Maybe String,
 fullconfigbase :: FullConfig
 fullconfigbase
   = FullConfig{headers = Nothing, resolution = 0,
-               outputFilename = "", inputUrl = "", runMode = HTML, paper = "A4",
+               outputFilename = "", inputUrl = "", runMode = HTML No, paper = "A4",
                vector = False, copy = Nothing, mainPath = "", server = Nothing,
                outputType = PlainPDF, selfTest = Nothing, compile = Nothing,
                imgctrb = Nothing}
