@@ -1,3 +1,4 @@
+{-# LANGUAGE DefaultSignatures, DeriveAnyClass #-}
 {-DHUN| module to download the wiki source text form the wiki website DHUN-}
 module Load where
 import ImperativeState
@@ -10,9 +11,9 @@ import System.Directory
 import System.FilePath.Posix
 import Text.ParserCombinators.Parsec hiding (try)
 import Text.Parsec.Prim
-import Codec.Binary.UTF8.String
+import Codec.Binary.UTF8.String as C
 import Data.String.HT
-import Data.ByteString
+import Data.ByteString as B
        hiding (takeWhile, isInfixOf, intercalate, concat, map, sort)
 import Data.List.Split
 import Data.Map as Map hiding (map)
@@ -25,6 +26,7 @@ import MediaWikiParser
 import Network.URL
 import Control.Monad.Except
 import System.Process
+import Data.Serialize as S (decode)
 
 notendyet ::
           (String -> ImperativeMonad String) ->
@@ -101,8 +103,8 @@ chapterAction wurl text
            _ -> return ""
   where d = (trim (takeWhile (/= '|') text))
 
-chapterAction2 :: FullWikiUrl -> String -> ImperativeMonad String
-chapterAction2 fu text
+chapterAction2 :: WikiUrl->String -> String -> ImperativeMonad String
+chapterAction2 wurl lema text
   = do pp <- liftIO (getpage d (wurl))
        case pp of
            Just p -> do _ <- addContributors d Nothing
@@ -110,11 +112,10 @@ chapterAction2 fu text
                           ("\n\ndhunparserurl " ++ d ++ "\n\n" ++ "= " ++ e ++ " =\n" ++ p)
            _ -> return ""
   where e = (trim (takeWhile (/= '|') text))
-        d = (removePrintVersion (lemma fu)) ++ "/" ++ e
-        wurl = wikiUrl fu
+        d = (removePrintVersion lema) ++ "/" ++ e
 
-chapterAction3 :: FullWikiUrl -> String -> ImperativeMonad String
-chapterAction3 fu text
+chapterAction3 :: WikiUrl -> String -> String -> ImperativeMonad String
+chapterAction3 wurl text lema
   = do pp <- liftIO (getpage d (wurl))
        case pp of
            Just p -> do _ <- addContributors d Nothing
@@ -122,8 +123,7 @@ chapterAction3 fu text
                           ("\n\ndhunparserurl " ++ d ++ "\n\n" ++ "= " ++ e ++ " =\n" ++ p)
            _ -> return ""
   where e = (trim (takeWhile (/= '|') text))
-        d = (removePrintVersion (lemma fu)) ++ "/ " ++ e
-        wurl = wikiUrl fu
+        d = (removePrintVersion lema) ++ "/ " ++ e
 
 includeAction :: WikiUrl -> String -> ImperativeMonad String
 includeAction = qIncludeAction
@@ -139,12 +139,12 @@ qIncludeAction wurl text
              _ -> return ""
   where d = (trim (takeWhile (/= '|') text))
 
-qBookIncludeAction :: WikiUrl -> String -> ImperativeMonad String
-qBookIncludeAction wurl text
+qBookIncludeAction :: FullConfig-> WikiUrl -> String ->  ImperativeMonad String
+qBookIncludeAction cfg wurl text 
   = if isInfixOf "Vorlage" text then return ("{{" ++ text ++ "}}")
       else
-      do pp <- (liftIO (print d)) >> liftIO (getBookpage d (wurl))
-         case pp of
+         do pp <- (liftIO (print d)) >> myfun
+            case pp of
              Just p -> do _ <- addContributors d Nothing
                           x <- noinclude wurl ("\n\ndhunparserurl " ++ d ++ "\n\n" ++ p)
                           st <- get
@@ -155,12 +155,17 @@ qBookIncludeAction wurl text
                           _ <- liftIO $
                                  system
                                    ("mediawiki2latex -x " ++
-                                      (Hex.hex (show (fullconfigbase{compile = Just tempdir}))))
-                          t <- liftIO $ Tools.readFile (tempdir </> "output")
-                          put st{loadacu = ((read t) ++ (loadacu st) :: [Anything Char])}
+                                      (Hex.hex (show (fullconfigbase{compile = Just tempdir, runMode= runMode cfg}))))
+                          t <- liftIO $ B.readFile (tempdir </> "output")
+                          put st{loadacu = ((case S.decode t of {Right k->k;_->[]})++ (loadacu st) :: [Anything Char])}
                           return x
              _ -> return ""
   where d = (trim (takeWhile (/= '|') text))
+        myfun = case (runMode cfg) of 
+                  HTML _ -> liftIO  (getBookpage d (wurl))
+                  (ExpandedTemplates _) ->  (loadMediaWiki d wurl) >>= (return . Just)
+                  _ -> (loadPlain d wurl Nothing)  >>= (return . Just)
+
 
 makeUrl :: String -> String -> String -> [Char]
 makeUrl lang theFam thePage
@@ -347,12 +352,12 @@ noinclude :: t -> String -> ImperativeMonad [Char]
 noinclude wurl
   = runAction "<noinclude>" "</noinclude>" (zeroAction wurl)
 
-runActions :: FullWikiUrl -> String -> ImperativeMonad String
-runActions fu text
+runActions :: WikiUrl -> String -> String-> ImperativeMonad String
+runActions wurl lema text
   = do x <- noinclude wurl text
-       y <- runAction "{{Druckversion Kapitel|" "}}" (chapterAction3 fu) x
-       v <- runAction "{{Print entry|" "}}" (chapterAction2 fu) y
-       z <- runAction "{{print entry|" "}}" (chapterAction2 fu) v
+       y <- runAction "{{Druckversion Kapitel|" "}}" (chapterAction3 wurl lema) x
+       v <- runAction "{{Print entry|" "}}" (chapterAction2 wurl lema) y
+       z <- runAction "{{print entry|" "}}" (chapterAction2 wurl lema) v
        a <- runAction "{{Print entry|" "}}" (chapterAction wurl) z
        b <- runAction "{{:" "}}" (includeAction wurl) a
        c <- runAction "{{:" "}}" (qIncludeAction wurl) b
@@ -365,12 +370,11 @@ runActions fu text
        j <- runAction "{{:" "}}" (qIncludeAction wurl) h
        _ <- runAction "{{:" "}}" (qIncludeAction wurl) i
        runAction "{{:" "}}" (qIncludeAction wurl) j
-  where wurl = wikiUrl fu
 
-runBookActions :: FullWikiUrl -> String -> ImperativeMonad String
-runBookActions fu text
+runBookActions :: FullWikiUrl -> String -> FullConfig ->ImperativeMonad String
+runBookActions fu text cfg
   = do x <- noinclude wurl text
-       runAction "[[" "]]" (qBookIncludeAction wurl) x
+       runAction "[[" "]]" (qBookIncludeAction cfg wurl) x
   where wurl = wikiUrl fu
 
 replacements :: String -> String
@@ -387,22 +391,21 @@ replacements x
       "{{Fortran:Vorlage: Table}}"
       "prettytable"
 
-loadPlain :: ImperativeState -> Maybe URL -> ImperativeMonad [Char]
-loadPlain st uu
-  = let fu = fullUrl st in
-      do pp <- liftIO (getpage (lemma fu) (wikiUrl fu))
+loadPlain :: String -> WikiUrl -> Maybe URL -> ImperativeMonad [Char]
+loadPlain lema wurl uu
+  =   do pp <- liftIO (getpage lema wurl)
          case pp of
-             Just p -> do _ <- addContributors (lemma fu) uu
-                          runActions fu p
-             _ -> throwError (DownloadError (lemma fu) (exportURL (url fu)))
+             Just p -> do _ <- addContributors lema uu
+                          runActions wurl lema p
+             _ -> throwError (DownloadError lema (show wurl))
 
-loadBook :: ImperativeState -> Maybe URL -> ImperativeMonad [Char]
-loadBook st uu
+loadBook :: ImperativeState -> Maybe URL -> FullConfig ->ImperativeMonad [Char]
+loadBook st uu cfg
   = let fu = fullUrl st in
       do pp <- liftIO (getpage (lemma fu) (wikiUrl fu))
          case pp of
              Just p -> do _ <- addContributors (lemma fu) uu
-                          runBookActions fu p
+                          runBookActions fu p cfg
              _ -> throwError (DownloadError (lemma fu) (exportURL (url fu)))
 
 loadHTML :: ImperativeState -> ImperativeMonad String
@@ -410,33 +413,32 @@ loadHTML st
   = let fu = fullUrl st in
       do midst <- get
          (res, newst) <- liftIO
-                           (runStateT (runExceptT (loadPlain st (Just (url fu)))) midst)
+                           (runStateT (runExceptT (loadPlain (lemma (fullUrl st)) (wikiUrl (fullUrl st)) (Just (url fu)))) midst)
          case res of
              Right _ -> put newst
              _ -> return ()
          x <- liftIO (geturl2 (exportURL (url fu)))
-         return . decode . unpack $ x
+         return . C.decode . unpack $ x
 
 loadBookHTML :: ImperativeState -> ImperativeMonad String
 loadBookHTML st
   = let fu = fullUrl st in
       do midst <- get
          (res, newst) <- liftIO
-                           (runStateT (runExceptT (loadPlain st (Just (url fu)))) midst)
+                           (runStateT (runExceptT (loadPlain (lemma (fullUrl st)) (wikiUrl (fullUrl st)) (Just (url fu)))) midst)
          case res of
              Right _ -> put newst
              _ -> return ()
          x <- liftIO (geturl2 (exportURL (url fu)))
-         return . decode . unpack $ x
+         return . C.decode . unpack $ x
 
-loadMediaWiki :: ImperativeState -> ImperativeMonad [Char]
-loadMediaWiki st
-  = let fu = fullUrl st in
-      do pp <- liftIO (getpage2 (lemma fu) (wikiUrl fu))
+loadMediaWiki :: String-> WikiUrl -> ImperativeMonad [Char]
+loadMediaWiki lema  wurl
+  =   do pp <- liftIO (getpage2 lema wurl)
          case pp of
-             Just (ss, u) -> do _ <- addContributors (lemma fu) Nothing
+             Just (ss, u) -> do _ <- addContributors lema Nothing
                                 s <- liftIO
-                                       (getExpandedPage (lemma fu)
+                                       (getExpandedPage lema
                                           (replace2
                                              (replace2
                                                 (replace2 ss "<ref name=" "dhunnamedrefopendhun")
@@ -454,17 +456,37 @@ loadMediaWiki st
                                                       ("dhunrefclosedhun", "</ref>")])
                                     _ -> do liftIO (print "Error")
                                             throwError
-                                              (DownloadError (lemma fu) (exportURL (url fu)))
-             _ -> throwError (DownloadError (lemma fu) (exportURL (url fu)))
+                                              (DownloadError lema (show wurl))
+             _ -> throwError (DownloadError lema  (show wurl))
 
 {-DHUN| main function to download images form the wiki. It takes the RunMode as only parameter. In case of HTML the html from the website is loaded. In all other cases the wiki source text is downloaded. In case of ExpandedTemplates the templates are also expanded by mediawiki running on the wiki website DHUN-}
 
-load :: RunMode -> ImperativeMonad String
-load theRunMode
+load :: FullConfig->ImperativeMonad String
+load cfg
   = do st <- get
-       case theRunMode of
-           HTML -> loadHTML st
-           Book -> loadBook st Nothing
-           UserTemplateFile _ -> loadPlain st Nothing
-           StandardTemplates -> loadPlain st Nothing
-           ExpandedTemplates -> loadMediaWiki st
+       case (runMode cfg) of
+           HTML Yes-> loadBook st Nothing cfg
+
+           UserTemplateFile Yes _ -> loadBook st Nothing cfg
+           StandardTemplates Yes -> loadBook st Nothing cfg
+           ExpandedTemplates Yes -> loadBook st Nothing cfg
+
+
+           HTML No -> loadHTML st
+           UserTemplateFile No _ -> loadPlain (lemma (fullUrl st)) (wikiUrl (fullUrl st)) Nothing
+           StandardTemplates No -> loadPlain (lemma (fullUrl st)) (wikiUrl (fullUrl st)) Nothing
+           ExpandedTemplates No -> loadMediaWiki (lemma (fullUrl st)) (wikiUrl (fullUrl st))
+
+
+
+
+
+
+
+
+
+
+
+
+
+
