@@ -4,9 +4,9 @@ import Data.Char
 import Network.URI
 import Data.List.Split
 import qualified Data.Map as Map
- 
+
 {-DHUN| Wikimedia project prefixes so 'de' from de.wikipedia.org DHUN-}
- 
+
 foreignPrefixes :: [String]
 foreignPrefixes
   = ["af", "als", "an", "roa-rup", "ast", "gn", "av", "ay", "az",
@@ -32,9 +32,9 @@ foreignPrefixes
      "kn", "ks", "ml", "mr", "ne", "new", "or", "pa", "sa", "si", "ta",
      "te", "km", "lo", "th", "am", "ti", "iu", "chr", "ko", "ja", "zh",
      "wuu", "lzh", "yue"]
- 
+
 {-DHUN| Wikimedia projects for interwiki links [[w:Foobar]] means en.wikipedia.org/wiki/Foobar DHUN-}
- 
+
 multilangwikis :: [(String, String)]
 multilangwikis
   = ([("w", "wikipedia"), ("wikipedia", "wikipedia"),
@@ -48,31 +48,31 @@ multilangwikis
            ++
            [("wikispecies", "wikispecies"), ("v", "wikiversity"),
             ("wikiversity", "wikiversity")])
- 
+
 {-DHUN| Wikimedia projects for interwiki links to wikis which only have got a single language version DHUN-}
- 
+
 singlelangwikis :: [(String, String)]
 singlelangwikis
   = [("wikimedia", "wikimediafoundation"),
      ("foundation", "wikimediafoundation"),
      ("wmf", "wikimediafoundation"), ("mw", "mediawiki")]
- 
+
 {-DHUN| Wikimedia projects for interwiki links to wikis which only have got a single language version DHUN-}
- 
+
 wikimediasingellangwikis :: [(String, String)]
 wikimediasingellangwikis
   = [("commons", "commons"), ("metawikipedia", "meta"),
      ("meta", "meta"), ("m", "meta"), ("incubator", "incubator"),
      ("strategy", "strategy")]
- 
+
 {-DHUN| All Wikis DHUN-}
- 
+
 allwikis :: [(String, String)]
 allwikis
   = multilangwikis ++ singlelangwikis ++ wikimediasingellangwikis
- 
+
 {-DHUN| Prefixes for including images in wikis DHUN-}
- 
+
 imgtags :: [[Char]]
 imgtags
   = [map toLower x |
@@ -96,22 +96,22 @@ imgtags
            "\1057\1083\1080\1082\1072", "Bild", "\3652\3615\3621\3660",
            "Talaksan", "Dosya", "\1496\1506\1511\1506", "\22294\20687",
            "\22294\20687"]]
- 
+
 {-DHUN| lower Greek letter for HTML entity to latex so &delta; to \\delta DHUN-}
- 
+
 lowergreek :: [[Char]]
 lowergreek
   = ["alpha", "beta", "gamma", "delta", "epsilon", "zeta", "eta",
      "theta", "iota", "kappa", "lambda", "mu", "nu", "xi", "pi", "rho",
      "sigma", "tau", "upsilon", "phi", "chi", "psi", "omega"]
- 
+
 {-DHUN| not Greek but to be processed like the Greeks above DHUN-}
- 
+
 notsogreek :: [[Char]]
 notsogreek = ["cap", "cup", "sim"]
- 
+
 {-DHUN| Full list of characters with Greek like processing explained above DHUN-}
- 
+
 greek :: [[Char]]
 greek
   = concat
@@ -120,9 +120,9 @@ greek
               (x : xs) -> return [(toUpper x) : xs]
               [] -> return [])
       ++ lowergreek ++ notsogreek
- 
+
 {-DHUN| HTML entities to latex DHUN-}
- 
+
 htmlchars :: [([Char], [Char])]
 htmlchars
   = [("thetasym", "{\\mbox{$\\vartheta$}}"),
@@ -505,29 +505,30 @@ htmlchars
      ("zwnj", "{}"), ("zwj", ""), ("lrm", ""), ("rlm", ""),
      ("gt", "{\\mbox{$>$}}"), ("Mu", "{\\mbox{$\\Mu$}}"),
      ("#151", "{--}"), ("Nu", "{\\mbox{$\\Nu$}}"), ("frasl", "\8260")]
- 
+
 {-DHUN| get latex representation of HTML entity like &amp; DHUN-}
- 
+
 getHtmlChar :: String -> String
 getHtmlChar x = Map.findWithDefault [] x (Map.fromList htmlchars)
- 
+
 {-DHUN| a function to remove the taling print version string from urls (usually on wikibooks). This function is needed so the name of the book without the tailing print version string will be printed on the titlepage of the book DHUN-}
- 
+
 removePrintVersion :: [Char] -> [Char]
 removePrintVersion lem
   = fun
-      ["/Druckversion","/ Druckversion","/Print version", "/Complete Wikibook", "/All Chapters",
-       "/Print Version", "/print version", "/Printable version",
-       "/The Whole Book", "/print", ": Druckversion"]
+      ["/Druckversion", "/ Druckversion", "/Print version",
+       "/Complete Wikibook", "/All Chapters", "/Print Version",
+       "/print version", "/Printable version", "/The Whole Book",
+       "/print", ": Druckversion"]
       lem
   where fun (y : ys) x
           = case splitOn y x of
                 (z : _) -> fun ys z
                 _ -> []
         fun [] x = x
- 
+
 {-DHUN| Nearly all HTML tags DHUN-}
- 
+
 goodtags1 :: [[Char]]
 goodtags1
   = ["includeonly", "references", "blockquote", "noinclude",
@@ -537,30 +538,30 @@ goodtags1
      "strike", "object", "input", "center", "legend", "iframe", "small",
      "video", "audio", "style", "input", "label", "tbody", "thead",
      "title", "frame", "param", "base", "area", "font", "code", "span",
-     "abbr", "body", "link", "menu", "math", "meta", "samp", "cite", "head",
-     "html", "poem", "form", "cite", "ref", "div", "pre", "sub", "sup",
-     "big", "del", "map", "bdo", "var", "dfn", "kbd", "col", "ins", "bdi",
-     "dir", "img", "h1", "h2", "h3", "h4", "h5", "h6", "li", "ul", "ol",
-     "tt", "dd", "dl", "dt", "hr", "em", "b", "i", "s", "u", "p", "q",
-     "a"]
- 
+     "abbr", "body", "link", "menu", "math", "meta", "samp", "cite",
+     "head", "html", "poem", "form", "cite", "ref", "div", "pre", "sub",
+     "sup", "big", "del", "map", "bdo", "var", "dfn", "kbd", "col",
+     "ins", "bdi", "dir", "img", "h1", "h2", "h3", "h4", "h5", "h6",
+     "li", "ul", "ol", "tt", "dd", "dl", "dt", "hr", "em", "b", "i",
+     "s", "u", "p", "q", "a"]
+
 {-DHUN| HTML tags for tables rows in tables and so on, only lower case DHUN-}
- 
+
 tabletags :: [[Char]]
 tabletags = ["table", "td", "th", "tr"]
- 
+
 {-DHUN| HTML tags for tables rows in tables and so on, lower case as well as upper case  DHUN-}
- 
+
 listOfTableTags :: [[Char]]
 listOfTableTags = tabletags ++ (map (map toUpper) tabletags)
- 
+
 {-DHUN| All HTML tags DHUN-}
- 
+
 listOfTags :: [[Char]]
 listOfTags = goodtags1 ++ (map (map toUpper) goodtags1)
- 
+
 {-DHUN| Character escaping from Unicode to latex DHUN-}
- 
+
 chartrans :: Char -> String
 chartrans '\'' = "\\textquotesingle{}"
 chartrans '[' = "{$\\text{[}$}"
@@ -579,11 +580,11 @@ chartrans '\\' = "\\textbackslash{}"
 chartrans '<' = "<{}"
 chartrans '>' = ">{}"
 chartrans '-' = "-{}"
-chartrans ' ' = "\\,"
+chartrans '\8239' = "\\,"
 chartrans c = c : []
- 
+
 {-DHUN| Character escaping from Unicode to web links inside latex with the URL package DHUN-}
- 
+
 chartransforlink :: Char -> String
 chartransforlink '&' = "\\&"
 chartransforlink '%' = "\\%"
