@@ -249,7 +249,7 @@ progressBar t sub
                         ok $
                           template "Conversion Finished" $
                             pageFrame $
-                              infoBox "Conversion Finished" $
+                              infoBox "Conversion Finished. Click on the arrow in the right upper corner of your browser in order to view the result." $
                                 do H.meta H.! A.httpEquiv "refresh" H.!
                                      A.content
                                        (stringValue
@@ -279,7 +279,7 @@ fileFrame t sub
            Just x -> do f <- serveFile (guessContentTypeM mimeTypes) x
                         _ <- liftIO
                                (forkIO
-                                  (do threadDelay 2000000
+                                  (do threadDelay 200000000
                                       removeFile x))
                         return f
            Nothing -> do method GET
@@ -383,11 +383,11 @@ formPage m s
                              H.br
                              mytext "Requests taking longer will be terminated and a \"Conversion Failed due to timeout or non zero exit code\" message will be displayed. There is no limit in the downloadable versions shown on the right." 
 
-        getRunmode "Print" = ImperativeState.HTML
-        getRunmode "MediaWiki" = ImperativeState.ExpandedTemplates
-        getRunmode "Normal" = ImperativeState.StandardTemplates
-        getRunmode "BookMode" = ImperativeState.Book
-        getRunmode _ = ImperativeState.HTML
+        getRunmode "Print" = ImperativeState.HTML ImperativeState.No
+        getRunmode "MediaWiki" = ImperativeState.ExpandedTemplates ImperativeState.No
+        getRunmode "Normal" = ImperativeState.StandardTemplates ImperativeState.No
+        getRunmode "BookMode" = ImperativeState.HTML ImperativeState.No 
+        getRunmode _ = ImperativeState.HTML ImperativeState.No
         
         processForm :: ServerPart Response
         processForm
