@@ -241,7 +241,7 @@ getpage ss u
 
 getBookpage :: String -> WikiUrl -> IO (Maybe String)
 getBookpage ss u
-  = do l <- mapM ((geturl2) . unify)  ((map ((++("wiki/"++ss)).exportURL)) (parses u))
+  = do l <- mapM ((geturl2) . unify)  ((map ((++("/"++ss)).exportURL)) (parses u))
        lll <- return (seq l l)
        return $
          (listToMaybe $ concat (map maybeToList (map go lll))) >>=
@@ -288,7 +288,7 @@ analyse :: String -> WikiUrl
 analyse s
   = do vv <- v
        ww <- importURL "https://commons.wikimedia.org/wiki"
-       return (vv, z ++ [ww])
+       return (vv, (reverse z) ++ [ww])
   where v = importURL s
          
         z :: [URL]
@@ -297,7 +297,7 @@ analyse s
                x <- (map
                        (\ i ->
                           if (length l) > i then [intercalate "/" (take i l)] else mzero)
-                       [0, 1, 2])
+                       [2, 0, 1])
                map (\ i -> u{url_path = i}) x
  
 {-DHUN| converts an url given as String into the lemma it points to on the wiki.  DHUN-}
