@@ -161,7 +161,7 @@ options
        "use MediaWiki to expand templates",
      Option ['h'] [html] (NoArg Main.HTML)
        "use MediaWiki generated html as input (default)",
-     Option ['k'] [bookmode] (NoArg BookMode)
+     Option ['k'] [bookmode] (NoArg Main.BookMode)
        "use book-namespace mode for expansion",
      Option ['z'] [Main.zip] (NoArg Main.Zip)
        "output zip archive of latex source",
@@ -194,7 +194,7 @@ header = "Usage: mediawiki2latex [OPTION...]"
 
 versionHeader :: String
 versionHeader
-  = "mediawiki2latex version 7.33\n" ++ (usageInfo header options)
+  = "mediawiki2latex version 7.34\n" ++ (usageInfo header options)
 
 {-DHUN| print the version string of mediawiki2latex. Takes the output of the compilerOpts function as input. Prints the version string if no options were given or the version command was given does noting otherwise DHUN-}
 
@@ -316,7 +316,7 @@ checkOpts cwd o
                                          return
                                            FullConfig{ImperativeState.headers = Nothing,
                                                       resolution = 300, outputFilename = "",
-                                                      inputUrl = "", runMode = ImperativeState.HTML,
+                                                      inputUrl = "", runMode = ImperativeState.HTML ImperativeState.No,
                                                       paper = "A4", vector = False,
                                                       ImperativeState.copy = Nothing, mainPath = "",
                                                       server = Nothing, selfTest = Just (s, e),
@@ -329,7 +329,7 @@ checkOpts cwd o
                                                 FullConfig{ImperativeState.headers = Nothing,
                                                            resolution = 300, outputFilename = "",
                                                            inputUrl = "",
-                                                           runMode = ImperativeState.HTML,
+                                                           runMode = ImperativeState.HTML ImperativeState.No,
                                                            paper = "A4", vector = False,
                                                            ImperativeState.copy = Nothing,
                                                            mainPath = "", server = Just z,
@@ -365,7 +365,7 @@ checkOpts cwd o
                                                                     Left PaperError
                                                         _ -> Right defaultPaper
                                         let mediaWikiVal = (MediaWiki `elem` o)
-                                        let bookModeVal = (BookMode `elem` o)
+                                        let bookModeVal = if (Main.BookMode `elem` o) then ImperativeState.Yes else ImperativeState.No 
                                         let htmlVal = (Main.HTML `elem` o)
                                         let zipVal = (Main.Zip `elem` o)
                                         let epubVal = (Main.EPub `elem` o)
@@ -376,7 +376,6 @@ checkOpts cwd o
                                               = (boolToInt temVal) + (boolToInt mediaWikiVal) +
                                                   (boolToInt htmlVal)
                                                   + (maybeToInt templatesVal)
-                                                  + (boolToInt bookModeVal)
                                         if mysum > 1 then Left ToManyOptionsError else Right ()
                                         if
                                           ((boolToInt zipVal) + (boolToInt epubVal) +
@@ -385,16 +384,13 @@ checkOpts cwd o
                                           then Left ToManyOutputOptionsError else Right ()
                                         runModeVal <- if mysum == (1 :: Integer) then
                                                         case templatesVal of
-                                                            Just xx -> Right (UserTemplateFile xx)
+                                                            Just xx -> Right (UserTemplateFile bookModeVal xx)
                                                             _ -> if mediaWikiVal then
-                                                                   Right ExpandedTemplates else
+                                                                   Right (ExpandedTemplates bookModeVal) else
                                                                    if htmlVal then
-                                                                     Right ImperativeState.HTML else
-                                                                     if bookModeVal then
-                                                                       Right ImperativeState.Book
-                                                                       else
-                                                                       Right (StandardTemplates)
-                                                        else Right ImperativeState.HTML
+                                                                     Right (ImperativeState.HTML bookModeVal) else
+                                                                     Right (StandardTemplates bookModeVal)
+                                                        else Right (ImperativeState.HTML bookModeVal)
                                         return
                                           (FullConfig{ImperativeState.headers =
                                                         headersVal >>= (return . (cwd </>)),
@@ -424,7 +420,7 @@ main
        cwd <- getCurrentDirectory
        case (checkOpts cwd (fst o)) of
            Right x -> case (compile x) of
-                          Just dir -> do _ <- (runStateT (runExceptT (runCompile dir)) stz)
+                          Just dir -> do _ <- (runStateT (runExceptT (runCompile dir x)) stz)
                                          return ()
                           _ -> case (imgctrb x) of
                                    Just dir -> do _ <- (runStateT (runExceptT (runCtrb dir)) stz)
